<?php
/**
 * Single Product Thumbnails
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-thumbnails.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post, $product, $woocommerce;

$mts_options = get_option( MTS_THEME_NAME );

if ( version_compare( $woocommerce->version, '3.0.0', ">=" ) ) {
	$attachment_ids = $product->get_gallery_image_ids();
	$lightbox_enabled = isset( $mts_options['mts_wc_product_gallery'] ) && '0' == $mts_options['mts_wc_product_gallery'];
} else {
	$attachment_ids = $product->get_gallery_attachment_ids();
	$lightbox_enabled = get_option( 'woocommerce_enable_lightbox' ) == 'yes';
}

if ( $attachment_ids ) {

	$classes = array( /*'zoom'*/ );
	?>
	<div id="product-img-nav" class="flexslider">
		<ul class="slides">
		<?php
		if ( has_post_thumbnail() ) {

			$image_title = esc_attr( get_the_title( get_post_thumbnail_id() ) );
			$image_link  = wp_get_attachment_url( get_post_thumbnail_id() );
			$image       = get_the_post_thumbnail( $post->ID, apply_filters( 'single_product_small_thumbnail_size', 'shop_thumbnail' ), array( 'title' => $image_title ) );
			$image_class = esc_attr( implode( ' ', $classes ) );

			echo '<li>';
			echo apply_filters( 'woocommerce_single_product_image_thumbnail_html', sprintf( '<a href="%s" class="%s" title="%s">%s</a>', $image_link, $image_class, $image_title, $image ), get_post_thumbnail_id(), $post->ID, $image_class );
			echo '</li>';

		}
		
		$columns = apply_filters( 'woocommerce_product_thumbnails_columns', 3 );

		foreach ( $attachment_ids as $attachment_id ) {

			$image_link = wp_get_attachment_url( $attachment_id );

			if ( ! $image_link )
				continue;

			$image       = wp_get_attachment_image( $attachment_id, apply_filters( 'single_product_small_thumbnail_size', 'shop_thumbnail' ) );
			$image_class = esc_attr( implode( ' ', $classes ) );
			$image_title = esc_attr( get_the_title( $attachment_id ) );

			echo '<li>';
			echo apply_filters( 'woocommerce_single_product_image_thumbnail_html', sprintf( '<a href="%s" class="%s" title="%s">%s</a>', $image_link, $image_class, $image_title, $image ), $attachment_id, $post->ID, $image_class );
			echo '</li>';
		}

		?>
		</ul>
		<?php  if ( $lightbox_enabled ) { echo '<a href="#" class="lightbox-icon"><i class="fa fa-expand"></i></a>'; } ?>
	</div>
	<?php
}